@@ -4,12 +4,6 @@ errormessage = (
 )
 
 
-class TPImportError(ImportError):
-    def __init__(self, message: str = ""):
-        self.message = f"Error in TransparentPath: {message}"
-        super().__init__(self.message)
-
-
 try:
     import json
     import warnings
@@ -23,6 +17,8 @@ try:
         """
 
         def default(self, obj: Any):
+            if obj.__class__.__name__ == "TransparentPath":
+                return str(obj)
             if hasattr(obj, "to_json"):
                 if callable(obj.to_json):
                     try:
@@ -63,4 +59,4 @@ try:
 
 
 except ImportError as e:
-    raise TPImportError(str(e))
+    raise ImportError(str(e))
